==> haskell-pattern-arrows-0.0.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pattern-arrows.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pattern-arrows
version: 0.0.2
id: pattern-arrows-0.0.2-2hNgUi6N1XWJzQ7A2NFG6V
key: pattern-arrows-0.0.2-2hNgUi6N1XWJzQ7A2NFG6V
license: MIT
copyright: (c) Phil Freeman 2013
maintainer: Phil Freeman <paf31@cantab.net>
stability: experimental
homepage: http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html
synopsis: Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.
category: Text, Combinators, Pretty Printer
author: Phil Freeman <paf31@cantab.net>
exposed: True
indefinite: False
exposed-modules:
    Control.PatternArrows
abi: fe9cbd5fb7485233f1a418143b67014d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pattern-arrows-0.0.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/pattern-arrows-0.0.2
hs-libraries: HSpattern-arrows-0.0.2-2hNgUi6N1XWJzQ7A2NFG6V
depends:
    base-4.10.0.0 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=5531911f09693672654e6de645ce55e7
haddock-interfaces: /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock
haddock-html: /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pattern-arrows-0.0.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pattern-arrows.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pattern-arrows
version: 0.0.2
id: pattern-arrows-0.0.2-C0FsYKzEv4VE2j5BSXsUB2
key: pattern-arrows-0.0.2-C0FsYKzEv4VE2j5BSXsUB2
license: MIT
copyright: (c) Phil Freeman 2013
maintainer: Phil Freeman <paf31@cantab.net>
stability: experimental
homepage: http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html
synopsis: Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.
category: Text, Combinators, Pretty Printer
author: Phil Freeman <paf31@cantab.net>
exposed: True
indefinite: False
exposed-modules:
    Control.PatternArrows
abi: 9474e6e506de0346deaf62768b8af992
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pattern-arrows-0.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/pattern-arrows-0.0.2
hs-libraries: HSpattern-arrows-0.0.2-C0FsYKzEv4VE2j5BSXsUB2
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
haddock-interfaces: /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock
haddock-html: /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
